import {
  Component,
  ElementRef,
  Inject,
  OnDestroy,
  ViewChild
} from "@angular/core";

import {
  ConnectedPositioningStrategy,
  IgxOverlayService,
  OverlaySettings,
  PositionSettings
} from "igniteui-angular";

import { Subject } from "rxjs";
import { filter, takeUntil } from "rxjs/operators";
import { OverlayCardComponent } from '../overlay-card/overlay-card.component';

@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss']
})
export class HomeComponent  implements OnDestroy {
  private destroy$ = new Subject<boolean>();
  private _overlayId: string;
  private _positionSettings: PositionSettings;

  @ViewChild("buttonElement", { static: true })
  private buttonElement: ElementRef;

  constructor(
    @Inject(IgxOverlayService) public overlayService: IgxOverlayService
  ) {
    //  overlay service deletes the id when onClosed is called. We should clear our id
    //  also in same event
    this.overlayService.onClosed
      .pipe(
        filter(x => x.id === this._overlayId),
        takeUntil(this.destroy$)
      )
      .subscribe(() => delete this._overlayId);
  }

  public showOverlay() {
    if (!this._overlayId) {
      // Initialize and use overlay settings
      const overlaySettings: OverlaySettings = {
        target: this.buttonElement.nativeElement,
        positionStrategy: new ConnectedPositioningStrategy(
          this._positionSettings
        )
      };
      this._overlayId = this.overlayService.attach(
        OverlayCardComponent,
        overlaySettings
      );
    }

    this.overlayService.show(this._overlayId);
  }

  public ngOnDestroy() {
    this.destroy$.next(true);
    this.destroy$.complete();
  }
}
